Learn R Programming

tashu (version 0.1.1)

monthly_bicycle_rental: Visualize the change of bicycle rental amount by temperature and each month.

Description

A function drawing a plot that shows change of temperature and bicycle rental ratio in each month.

Usage

monthly_bicycle_rental()

Arguments

Examples

Run this code
# NOT RUN {
monthly_bicycle_rental()
# }

Run the code above in your browser using DataLab