powered by
A function drawing a plot that shows change of temperature and bicycle rental ratio in each month.
monthly_bicycle_rental()
# NOT RUN { monthly_bicycle_rental() # }
Run the code above in your browser using DataLab